==> enterprisemodules-pg_config-0.4.2.tar.gz: enterprisemodules-pg_config-0.4.2/lib/puppet/type/pg_parameter.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/read_only_property'

Puppet::Type.newtype(:pg_parameter) do
  include EasyType
  include Puppet_X::EnterpriseModules::Postgres::Access
  extend Puppet_X::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
  This type allows you to manage the postgres parameters. Here is an example on how you can use this:

      pg_parameter {"jit_debugging_support@db":
        value   => 'off',
      }

  The type will take care of setting the parameter settings and reloading the new configuration.
  DOC

  ensurable

  to_get_raw_resources do
    sql_on_all_databases "select name, encode(setting::bytea, 'base64') as setting, unit, vartype from pg_settings;"
  end

  on_create do
    fail "postgres parameter #{name}, does not exist."
  end

  on_modify do
    [:sql, "alter system set #{parameter_name} = #{specified_value}", { :db => db }]
  end

  after_modify do
    sql('select pg_reload_conf()', :db => db)
  end

  on_destroy do
    fail "You cannot absent postgres parameter #{name}."
  end

  def specified_value
    fail 'pg_parameter must contain a value' unless self[:value]
    vartype_to_use = vartype || provider.vartype

    if vartype_to_use == 'integer' || vartype_to_use == 'bool'
      self[:value]
    else
      "'#{self[:value]}'"
    end
  end

  map_title_to_db(:parameter_name)

  parameter :name
  parameter :parameter_name
  parameter :db

  property  :value
  property  :vartype
  property  :unit
end

==> enterprisemodules-pg_config-0.5.0.tar.gz: enterprisemodules-pg_config-0.5.0/lib/puppet/type/pg_parameter.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/read_only_property'

Puppet::Type.newtype(:pg_parameter) do
  include EasyType
  include Puppet_X::EnterpriseModules::Postgres::Access
  extend Puppet_X::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
  This type allows you to manage the postgres parameters. Here is an example on how you can use this:

      pg_parameter {"jit_debugging_support@db":
        value   => 'off',
      }

  The type will take care of setting the parameter settings and reloading the new configuration.
  DOC

  ensurable

  to_get_raw_resources do
    sql_on_cluster_databases "select name, encode(setting::bytea, 'base64') as setting, unit, vartype from pg_settings;"
  end

  on_create do
    fail "postgres parameter #{name}, does not exist."
  end

  on_modify do
    [:sql, "alter system set #{parameter_name} = #{specified_value}", { :db => db }]
  end

  after_modify do
    sql('select pg_reload_conf()', :db => db)
  end

  on_destroy do
    fail "You cannot absent postgres parameter #{name}."
  end

  def specified_value
    fail 'pg_parameter must contain a value' unless self[:value]

    vartype_to_use = vartype || provider.vartype

    if %w[integer bool].include?(vartype_to_use)
      self[:value]
    else
      "'#{self[:value]}'"
    end
  end

  map_title_to_db(:parameter_name)

  parameter :name
  parameter :parameter_name
  parameter :db

  property  :value
  property  :vartype
  property  :unit
end
